============
Installation
============

via `pip <https://pip.pypa.io/>`_
-------------------------------------------
* from `PyPI <https://pypi.org/p/aiosend/>`_

.. code-block:: bash

    pip install -U aiosend

* from `GitHub <https://github.com/vovchic17/aiosend>`_

.. code-block:: bash

    pip install https://github.com/vovchic17/aiosend/archive/refs/heads/main.zip

via `uv <https://docs.astral.sh/uv/>`_
--------------------------------------
.. code-block:: bash

    uv add aiosend

via `Poetry <https://python-poetry.org/>`_
------------------------------------------
.. code-block:: bash

    poetry add aiosend

via `PDM <https://pdm-project.org/>`_
-----------------------------------------------
.. code-block:: bash

    pdm add aiosend

via `pipx <https://pipx.pypa.io/>`_
-----------------------------------------------
.. code-block:: bash

    pipx install aiosend

via `Rye <https://rye.astral.sh/>`_
-----------------------------------------------
.. code-block:: bash

    rye add aiosend

via `Conda <https://docs.conda.io/>`_
-----------------------------------------------
.. code-block:: bash

    conda install aiosend

via `Pipenv <https://pipenv.pypa.io/>`_
-----------------------------------------------
.. code-block:: bash

    pipenv install aiosend
